@@ -16,16 +16,14 @@ from cadence_sdk.base.metadata import ModelConfig, PluginMetadata
 from cadence_sdk.base.plugin import BasePlugin
 from cadence_sdk.registry.plugin_registry import PluginRegistry, discover_plugins, get_plugin_registry, register_plugin
 from cadence_sdk.tools.decorators import tool
-from cadence_sdk.tools.registry import ToolRegistry
 
-__version__ = "1.0.5"
+__version__ = "1.0.10"
 __all__ = [
     "BaseAgent",
     "BasePlugin",
     "PluginMetadata",
     "ModelConfig",
     "PluginRegistry",
-    "ToolRegistry",
     "tool",
     "discover_plugins",
     "register_plugin",
