@@ -13,7 +13,7 @@ class TemplatePlugin(BasePlugin):
         """Return plugin metadata."""
         return PluginMetadata(
             name="template_plugin",
-            version="1.0.5",
+            version="1.0.10",
             description="Template plugin demonstrating Cadence SDK usage",
             capabilities=[
                 "example_capability",
@@ -27,7 +27,7 @@ class TemplatePlugin(BasePlugin):
                 "max_tokens": 1024,
             },
             agent_type="specialized",
-            dependencies=["cadence_sdk>=1.0.1,<2.0.0"],
+            dependencies=["cadence-sdk>=1.0.7,<2.0.0"],
         )
 
     @staticmethod
